@@ -2,6 +2,7 @@
 
 try:
     import text_editing
+
     COLOR = True
 except ModuleNotFoundError:
     COLOR = False
@@ -54,17 +55,19 @@ def str_object(obj: typing.Any, tab: int = 0, pass_: bool = False) -> str:
     """
     try:
         max_key_length = max([len(key) for key in obj.__dict__])
-        txt = ('\t'*tab + f"{text_editing.color.COLOR_PURPLE if COLOR else ''}"
-                          f"{obj.__class__.__name__} : \n") if not pass_ else '\n'
+        max_type_length = max([len(str(type(obj.__dict__[key]).__name__)) for key in obj.__dict__])
+        txt = ('\t' * tab + f"{text_editing.color.COLOR_PURPLE if COLOR else ''}"
+                            f"{obj.__class__.__name__} : \n") if not pass_ else '\n'
 
         for key in obj.__dict__:
-            txt += '\t'*tab + f"\t - {key.center(max_key_length, ' ')} ({type(obj.__dict__[key]).__name__}) : " \
-                              f"{str_object(obj.__dict__[key], tab + 1, True)}\n"
+            txt += '\t' * tab + f"\t - {key.center(max_key_length, ' ')} " \
+                                f"({str(type(obj.__dict__[key]).__name__).center(max_type_length)}) : " \
+                                f"{str_object(obj.__dict__[key], tab + 1, True)}\n"
 
         return txt[:-1]
-    except AttributeError:
-        txt = ('\t'*tab + f"{text_editing.color.COLOR_YELLOW if COLOR else ''}"
-                          f"{obj.__class__.__name__} : ") if not pass_ else ''
+    except Exception as _:
+        txt = ('\t' * tab + f"{text_editing.color.COLOR_YELLOW if COLOR else ''}"
+                            f"{obj.__class__.__name__} : ") if not pass_ else ''
         txt += f"{text_editing.color.COLOR_GREEN if COLOR else ''}" \
                f"{str(obj)}"
         return txt
